# xpip

> Python package. Build. Install.

## Language

- **[简体中文](docs/zh-Hans/README.md)**

## Features

The xpip can simplify the building and installation of Python packages, allowing developers to focus on code.

It provides the following toolkits:

- **Easily and quickly build and install Python package via [xpip-build](docs/xpip-build.md)**
- **Upload package to PyPI repository via [xpip-upload](docs/xpip-upload.md)**
- **Manage mirror via [xpip-mirror](docs/xpip-mirror.md)**

## Makefile

Create the [Makefile](docs/Makefile) for your project to easily and quickly build and upload Python package.
